@@ -80,8 +80,10 @@ static void populate_app_list               (ServiceEditDialog *dialog);
 static void store_data                      (ServiceEditDialog *dialog);
 static gboolean validate_data               (ServiceEditDialog *dialog);
 
+#ifdef SUPPORT_CHECK_CONTENT
 static void program_sensitive_cb            (ServiceEditDialog *dialog,
 					     GtkToggleButton   *tb);
+#endif
 static void program_changed_cb              (ServiceEditDialog *dialog,
 					     GtkOptionMenu     *option_menu);
 
@@ -131,13 +133,15 @@ service_edit_dialog_init (ServiceEditDialog *dialog, ServiceEditDialogClass *cla
 
 	dialog->p->dialog_win = gtk_dialog_new_with_buttons
 		(_("Edit service information"), NULL, -1,
-		 GTK_STOCK_OK,     GTK_RESPONSE_OK,
 		 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		 GTK_STOCK_OK,     GTK_RESPONSE_OK,
 		 NULL);
 
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog->p->dialog_win)->vbox), WID ("service_edit_widget"), TRUE, TRUE, 0);
 
+#ifdef SUPPORT_CHECK_CONTENT
 	g_signal_connect_swapped (G_OBJECT (WID ("run_program_toggle")), "toggled", (GCallback) program_sensitive_cb, dialog);
+#endif /* SUPPORT_CHECK_CONTENT */
 	g_signal_connect_swapped (G_OBJECT (WID ("program_select")), "changed", (GCallback) program_changed_cb, dialog);
 
 	g_signal_connect_swapped (G_OBJECT (dialog->p->dialog_win), "response", (GCallback) response_cb, dialog);
@@ -217,6 +221,8 @@ service_edit_dialog_set_prop (GObject *object, guint prop_id, const GValue *valu
 		if (dialog->p->is_add) {
 			dialog->p->info = service_info_new (NULL, NULL);
 			setup_add_dialog (dialog);
+			gtk_window_set_title (GTK_WINDOW (dialog->p->dialog_win),
+				(_("Add service")));
 			gtk_widget_show_all (dialog->p->dialog_win);
 		}
 
@@ -330,15 +336,13 @@ fill_dialog (ServiceEditDialog *dialog)
 		gtk_widget_set_sensitive (WID ("protocol_entry"), FALSE);
 	}
 
-#if 0  /* Keep the look at content toggle disabled until we support that in libgnome */
+#ifdef SUPPORT_CHECK_CONTENT 
+	/* Keep the look at content toggle disabled until we support that in libgnome */
 	if (gnome_vfs_method_get (dialog->p->info->protocol) == NULL)
 		gtk_widget_set_sensitive (WID ("look_at_content_toggle"), FALSE);
-#else
-		gtk_widget_set_sensitive (WID ("look_at_content_toggle"), FALSE);
-#endif
-
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("look_at_content_toggle")), !dialog->p->info->run_program);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("run_program_toggle")), dialog->p->info->run_program);
+#endif
 
 	if (!dialog->p->info->run_program && strcmp (dialog->p->info->protocol, "ftp"))
 		gtk_widget_set_sensitive (WID ("program_frame"), FALSE);
@@ -358,14 +362,17 @@ setup_add_dialog (ServiceEditDialog *dialog)
 
 	gtk_widget_set_sensitive (WID ("program_select"), FALSE);
 
+#ifdef SUPPORT_CHECK_CONTENT 
+	/* Disabled above so ignore it here */
 	gtk_widget_set_sensitive (WID ("look_at_content_toggle"), FALSE);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("run_program_toggle")), TRUE);
+#endif
 }
 
 static void
 populate_app_list (ServiceEditDialog *dialog) 
 {
-	GtkOptionMenu *option_menu;
+	GtkOptionMenu *program_select;
 	GtkMenu       *menu;
 	GtkWidget     *item;
 	gint           found_idx = -1, i = 0;
@@ -373,12 +380,12 @@ populate_app_list (ServiceEditDialog *dialog)
 	const GList   *service_apps;
 	GnomeVFSMimeApplication *app;
 
-	option_menu = GTK_OPTION_MENU (WID ("program_select"));
+	program_select = GTK_OPTION_MENU (WID ("program_select"));
 	menu = GTK_MENU (gtk_menu_new ());
 	service_apps = get_apps_for_service_type (dialog->p->info->protocol);
 
 	if (service_apps == NULL)
-		gtk_widget_set_sensitive (WID ("program_select"), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (program_select), FALSE);
 
 	while (service_apps != NULL) {
 		app = service_apps->data;
@@ -400,19 +407,13 @@ populate_app_list (ServiceEditDialog *dialog)
 	item = gtk_menu_item_new_with_label (_("Custom"));
 	gtk_widget_show (item);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	if (found_idx < 0)
+		found_idx = i;
 
-	if (found_idx < 0) {
-		if (dialog->p->info->app != NULL) {
-			if (dialog->p->info->app->command != NULL)
-				gnome_file_entry_set_filename (GNOME_FILE_ENTRY (WID ("custom_program_entry")),
-							       dialog->p->info->app->command);
-
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("needs_terminal_toggle")),
-						      dialog->p->info->app->requires_terminal);
-		}
-	}
-
-	gtk_option_menu_set_menu (option_menu, GTK_WIDGET (menu));
+	gtk_option_menu_set_menu (program_select, GTK_WIDGET (menu));
+	gtk_option_menu_set_history (program_select, found_idx);
+	/* fire it again just in case we had selected the 1st element */
+	program_changed_cb (dialog, program_select);
 }
 
 static void
@@ -434,8 +435,12 @@ store_data (ServiceEditDialog *dialog)
 	g_free (dialog->p->info->description);
 	dialog->p->info->description = g_strdup (gtk_entry_get_text (GTK_ENTRY (WID ("description_entry"))));
 
-	dialog->p->info->run_program =
+#ifdef SUPPORT_CHECK_CONTENT 
+	dialog->p->info->run_program = 
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (WID ("run_program_toggle")));
+#else
+	dialog->p->info->run_program = TRUE;
+#endif
 
 	option_menu = GTK_OPTION_MENU (WID ("program_select"));
 	menu_shell = GTK_MENU_SHELL (gtk_option_menu_get_menu (option_menu));
@@ -461,7 +466,7 @@ store_data (ServiceEditDialog *dialog)
 			= gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (WID ("needs_terminal_toggle")));
 	}
 
-	model_entry_append_to_dirty_list (MODEL_ENTRY (dialog->p->info));
+	model_entry_save (MODEL_ENTRY (dialog->p->info));
 
 	if (dialog->p->is_add) {
 		model_entry_insert_child (get_services_category_entry (dialog->p->model),
@@ -529,6 +534,7 @@ validate_data (ServiceEditDialog *dialog)
 	return TRUE;
 }
 
+#ifdef SUPPORT_CHECK_CONTENT
 static void
 program_sensitive_cb (ServiceEditDialog *dialog, GtkToggleButton *tb) 
 {
@@ -538,12 +544,15 @@ program_sensitive_cb (ServiceEditDialog *dialog, GtkToggleButton *tb)
 		 strcmp (dialog->p->info->protocol, "ftp"))
 		gtk_widget_set_sensitive (WID ("program_frame"), FALSE);
 }
+#endif
 
 static void
 program_changed_cb (ServiceEditDialog *dialog, GtkOptionMenu *option_menu)
 {
 	int id;
 	GtkMenuShell *menu;
+	GnomeVFSMimeApplication *app;
+	GList *child;
 
 	menu = GTK_MENU_SHELL (gtk_option_menu_get_menu (option_menu));
 	id = gtk_option_menu_get_history (option_menu);
@@ -555,6 +564,19 @@ program_changed_cb (ServiceEditDialog *dialog, GtkOptionMenu *option_menu)
 		gtk_widget_set_sensitive (WID ("program_entry_box"), FALSE);
 		gtk_widget_set_sensitive (WID ("needs_terminal_toggle"), FALSE);
 	}
+
+	child = g_list_nth (menu->children, id);
+	g_return_if_fail (child != NULL);
+
+	app = g_object_get_data (G_OBJECT (child->data), "app");
+	if (app == NULL) 
+		app = dialog->p->info->app;
+	if (app->command != NULL)
+		gnome_file_entry_set_filename (GNOME_FILE_ENTRY (WID ("custom_program_entry")),
+			app->command);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("needs_terminal_toggle")),
+		app->requires_terminal);
 }
 
 static void
